@@ -14,7 +14,7 @@ CaseData[65] = {
     "leanBodyMass": 72, 
     "learningObj": "", 
     "possiblePoints": 1000, 
-    "preopMsg": "\n22 year old with septic knee and diabetic ketoacidosis\n\nHistory of Present Illness\nDiabetic patient has fevers and chills with a painful, swollen, and inflamed knee.\n\nPast Medical History\nIllnesses: Insulin dependent diabetes mellitus\nSurgeries: none\nMeds: Insulin 20 Units NPH and 10 Units regular every morning plus 10 Units NPH and 5 Units regular every evening\nAllergies: none\nHabits: smokes, drinks, and uses intravenous drugs\n\nFamily History\nNo family history of anesthetic problems.\n\nPhysical Exam\nThin male, somewhat confused, anxious, and hyperventilating\nWeight: 72 Kg   T: 39.2   HR: 122   BP: 106/60   RR: 24\nAirway: normal\nLungs : clear  \nHeart : normal\n\nLabs\nHCT: 48    WBC : 18.2  Glucose: 548\nNa: 135     K: 3.8    Cl: 102    HCO3: 14    BUN: 10  Cr: 0.8\n\nNPO Status\nThe patient last ate 13 hours ago. \n\nPatient and Surgeon Requests\nThe patient refuses regional anesthesia. The surgeon states the procedure will take 1 hour.\n\n", 
+    "preopMsg": "\n22 year old with septic knee and diabetic ketoacidosis\n\nHistory of Present Illness\nDiabetic patient has fevers and chills with a painful, swollen, and inflamed knee.\n\nPast Medical History\nIllnesses - Insulin dependent diabetes mellitus\nSurgeries - none\nMeds - Insulin 20 Units NPH and 10 Units regular every morning plus 10 Units NPH and 5 Units regular every evening\nAllergies - none\nHabits - smokes, drinks, and uses intravenous drugs\n\nFamily History\nNo family history of anesthetic problems.\n\nPhysical Exam\nThin male, somewhat confused, anxious, and hyperventilating\nWeight: 72 Kg\nHR 122,  BP 106/60,  RR 24,  T 39.2   \nAirway - normal\nLungs - clear  \nHeart - normal\n\nLabs\nHematocrit 48,  WBC 18.2\nGlucose 548\nNa 135,  K 3.8,  Cl 102,  HCO3 14\nBUN 10,  Cr 0.8\n\nNPO Status\nThe patient last ate 13 hours ago. \n\nPatient and Surgeon Requests\nThe patient refuses regional anesthesia. The surgeon states the procedure will take 1 hour.\n\n", 
     "volAnDsp": 80, 
     "states": [
         {
@@ -48,7 +48,7 @@ CaseData[65] = {
             "papW": 3, 
             "pulseMsg": "The pulse is weak and rapid.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Awake, alert, and anxiously awaiting induction.", 
             "rhythm": "Sinus1", 
@@ -110,7 +110,7 @@ CaseData[65] = {
                 }, 
                 {
                     "nextState": "SEDATEDRY", 
-                    "comment": "You administered a sedative agent. (+50 of 100 points)", 
+                    "comment": "You administered a sedative agent.", 
                     "conditions": [
                         {
                             "op": "GT", 
@@ -118,7 +118,7 @@ CaseData[65] = {
                             "value": 0.2
                         }
                     ], 
-                    "points": 50
+                    "points": 0
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -129,7 +129,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -200
+                    "points": -500
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -140,7 +140,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -300
+                    "points": -500
                 }, 
                 {
                     "nextState": "HURT5", 
@@ -198,7 +198,7 @@ CaseData[65] = {
             "papW": 5, 
             "pulseMsg": "The pulse is stronger but still fast.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Insulin administered and partially rehydrated.", 
             "rhythm": "Sinus1", 
@@ -250,7 +250,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -200
+                    "points": -500
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -261,7 +261,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -300
+                    "points": -500
                 }, 
                 {
                     "nextState": "HURT5", 
@@ -319,7 +319,7 @@ CaseData[65] = {
             "papW": 8, 
             "pulseMsg": "The pulse is strong and regular.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Insulin administered and adequately rehydrated.", 
             "rhythm": "Sinus1", 
@@ -359,7 +359,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -200
+                    "points": -500
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -370,7 +370,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -300
+                    "points": -500
                 }, 
                 {
                     "nextState": "HURT5", 
@@ -428,7 +428,7 @@ CaseData[65] = {
             "papW": 2, 
             "pulseMsg": "The pulse is fast but weak.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Sedated but ketoacidosis not adequately treated.", 
             "rhythm": "Sinus1", 
@@ -509,7 +509,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -200
+                    "points": -500
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -520,7 +520,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -300
+                    "points": -500
                 }, 
                 {
                     "nextState": "HURT5", 
@@ -578,7 +578,7 @@ CaseData[65] = {
             "papW": 5, 
             "pulseMsg": "The pulse is fast and weak.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Insulin administered, partially rehydrated and sedated.", 
             "rhythm": "Sinus1", 
@@ -619,7 +619,7 @@ CaseData[65] = {
                             "value": 0.6
                         }
                     ], 
-                    "points": -100
+                    "points": -400
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -630,7 +630,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -100
+                    "points": -500
                 }, 
                 {
                     "nextState": "PARA5", 
@@ -642,7 +642,7 @@ CaseData[65] = {
                             "value": 0.8
                         }
                     ], 
-                    "points": -100
+                    "points": -500
                 }, 
                 {
                     "nextState": "HURT5", 
@@ -688,7 +688,7 @@ CaseData[65] = {
             "papW": 8, 
             "pulseMsg": "The pulse is strong.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Insulin administered and adequately rehydrated.", 
             "rhythm": "Sinus1", 
@@ -764,7 +764,7 @@ CaseData[65] = {
             "papW": 3, 
             "pulseMsg": "The pulse is fast.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Upset and coughing. ST depression is present.", 
             "rhythm": "St3", 
@@ -797,7 +797,7 @@ CaseData[65] = {
                 }, 
                 {
                     "nextState": "ASLEEPVERYDRY", 
-                    "comment": "The sedative agent is starting to take effect. (+25 points)", 
+                    "comment": "The sedative agent is starting to take effect.", 
                     "conditions": [
                         {
                             "op": "GT", 
@@ -805,7 +805,7 @@ CaseData[65] = {
                             "value": 0.6
                         }
                     ], 
-                    "points": 25
+                    "points": 0
                 }, 
                 {
                     "nextState": "HURT5", 
@@ -880,7 +880,7 @@ CaseData[65] = {
             "papW": 3, 
             "pulseMsg": "The pulse is fast.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Screaming and writhing in pain. ST depression is present.", 
             "rhythm": "St3", 
@@ -921,7 +921,7 @@ CaseData[65] = {
                             "value": 0.6
                         }
                     ], 
-                    "points": -100
+                    "points": -500
                 }, 
                 {
                     "nextState": "DESATBRADY1", 
@@ -968,7 +968,7 @@ CaseData[65] = {
             "papW": 3, 
             "pulseMsg": "The pulse is fast", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 20, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Awake but paralyzed.", 
             "rhythm": "St3", 
@@ -1009,7 +1009,7 @@ CaseData[65] = {
                             "value": 0.6
                         }
                     ], 
-                    "points": -100
+                    "points": -500
                 }, 
                 {
                     "nextState": "DESATBRADY1", 
@@ -1056,7 +1056,7 @@ CaseData[65] = {
             "papW": 2, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Anesthetized but only partially rehydrated.", 
             "rhythm": "Sinus1", 
@@ -1129,7 +1129,7 @@ CaseData[65] = {
                             "value": 180
                         }
                     ], 
-                    "points": -50
+                    "points": -300
                 }
             ]
         }, 
@@ -1164,7 +1164,7 @@ CaseData[65] = {
             "papW": 2, 
             "pulseMsg": "The pulse is weak.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Anesthetized without adequate resuscitation. The patient is now hypotensive and has ST depression.", 
             "rhythm": "St3", 
@@ -1240,7 +1240,7 @@ CaseData[65] = {
             "papW": 18, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Cardiac arrest!", 
             "rhythm": "Vfib2", 
@@ -1295,7 +1295,7 @@ CaseData[65] = {
             "heartSoundsMsg": "Regular rate and rhythm, without murmurs.", 
             "hiCo2ProdFlag": false, 
             "laryTubeSuccess": 1, 
-            "lidReflexMsg": "The lid reflex is slowed.", 
+            "lidReflexMsg": "The lid reflex is minimal.", 
             "lmaSuccessFlag": true, 
             "mentalStatusMsg": "The patient is unresponsive.", 
             "papD": 14, 
@@ -1304,7 +1304,7 @@ CaseData[65] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are small.", 
-            "rateEbl": 8, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Lightly anesthetized.", 
             "rhythm": "Sinus1", 
@@ -1403,7 +1403,7 @@ CaseData[65] = {
             "heartSoundsMsg": "Regular rate and rhythm, without murmurs.", 
             "hiCo2ProdFlag": false, 
             "laryTubeSuccess": 1, 
-            "lidReflexMsg": "The lid reflex is slowed.", 
+            "lidReflexMsg": "The lid reflex is minimal.", 
             "lmaSuccessFlag": true, 
             "mentalStatusMsg": "The patient is unresponsive.", 
             "papD": 14, 
@@ -1412,7 +1412,7 @@ CaseData[65] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are small.", 
-            "rateEbl": 8, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Lightly anesthetized.", 
             "rhythm": "Sinus1", 
@@ -1440,7 +1440,7 @@ CaseData[65] = {
                             "value": true
                         }
                     ], 
-                    "points": -100
+                    "points": -500
                 }, 
                 {
                     "nextState": "GA2", 
@@ -1499,7 +1499,7 @@ CaseData[65] = {
             "papW": 12, 
             "pulseMsg": "The pulse is strong.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 8, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Lightly anesthetized but autonomic response to painful stimulus.", 
             "rhythm": "Sinus1", 
@@ -1587,7 +1587,7 @@ CaseData[65] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Adequately anesthetized.", 
             "rhythm": "Sinus1", 
@@ -1673,7 +1673,7 @@ CaseData[65] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Deeply anesthetized.", 
             "rhythm": "Sinus1", 
@@ -1690,33 +1690,7 @@ CaseData[65] = {
             "sputumAmount": 0, 
             "stSegII": -0.5, 
             "stSegV5": 3, 
-            "temperature": 36.9, 
-            "trans": [
-                {
-                    "nextState": "GA4", 
-                    "comment": "You administered an excessively deep anesthetic. (Lost points)", 
-                    "conditions": [
-                        {
-                            "op": "GT", 
-                            "type": "doa", 
-                            "value": 3
-                        }
-                    ], 
-                    "points": -100
-                }, 
-                {
-                    "nextState": "DESATBRADY1", 
-                    "comment": "You allowed the patient to become severely hypoxic. (-1000 points)", 
-                    "conditions": [
-                        {
-                            "op": "LT", 
-                            "type": "o2Sat", 
-                            "value": 63
-                        }
-                    ], 
-                    "points": -1000
-                }
-            ]
+            "temperature": 36.9 
         }, 
         {
             "name": "GA4", 
@@ -1749,7 +1723,7 @@ CaseData[65] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Very deeply anesthetized.", 
             "rhythm": "Sinus1", 
@@ -1825,7 +1799,7 @@ CaseData[65] = {
             "papW": 8, 
             "pulseMsg": "The pulse is weak and slow.", 
             "pupilsMsg": "The pupils are small.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Hypoxic and bradycardic.", 
             "rhythm": "Sinus1", 
@@ -1889,7 +1863,7 @@ CaseData[65] = {
             "papW": 8, 
             "pulseMsg": "The pulse is weak and very slow.", 
             "pupilsMsg": "The pupils are large.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Hypoxic and severely bradycardic.", 
             "rhythm": "Sinus1", 
@@ -1954,7 +1928,7 @@ CaseData[65] = {
             "papW": 18, 
             "pulseMsg": "The pulse is absent.", 
             "pupilsMsg": "The pupils are large.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "Hypoxic and asystolic.", 
             "rhythm": "Asystole1", 
@@ -2019,7 +1993,7 @@ CaseData[65] = {
             "papW": 18, 
             "pulseMsg": "The pulse is absent.", 
             "pupilsMsg": "The pupils are fixed and dilated.", 
-            "rateEbl": 5, 
+            "rateEbl": 0, 
             "rateUo": 1.5, 
             "recordMsg": "The patient cannot be resuscitated.", 
             "rhythm": "Asystole1", 
