@@ -1,8 +1,17 @@
-sinus6[50] = {
-    "HemoNpoints": 120, 
-    "RhythmDescription": "Idioventricular (sinusoidal)", 
-    "RhythmRate": 50, 
+sinus2[70] = {
+    "HemoNpoints": 86, 
+    "RhythmDescription": "Sinus Rhythm with bifid P wave", 
+    "RhythmRate": 70, 
     "hemoPoints": [
+        {
+            "AbpHt": -2, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -4, 
+            "SpHt": -3
+        }, 
         {
             "AbpHt": -1, 
             "CvpHt": 0, 
@@ -15,7 +24,16 @@ sinus6[50] = {
         {
             "AbpHt": -1, 
             "CvpHt": 0, 
-            "EcgIIHt": 1, 
+            "EcgIIHt": -1, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": 0, 
+            "EcgIIHt": -2, 
             "EcgTag": 0, 
             "EcgV5Ht": -1, 
             "PapHt": -3, 
@@ -23,8 +41,8 @@ sinus6[50] = {
         }, 
         {
             "AbpHt": -1, 
-            "CvpHt": 0, 
-            "EcgIIHt": 2, 
+            "CvpHt": -1, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
             "EcgV5Ht": -2, 
             "PapHt": -3, 
@@ -32,514 +50,496 @@ sinus6[50] = {
         }, 
         {
             "AbpHt": -1, 
-            "CvpHt": 0, 
+            "CvpHt": -1, 
+            "EcgIIHt": -3, 
+            "EcgTag": 0, 
+            "EcgV5Ht": -2, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": -1, 
+            "EcgIIHt": -2, 
+            "EcgTag": 0, 
+            "EcgV5Ht": -1, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": -1, 
+            "EcgIIHt": -1, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -2
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": -2, 
+            "EcgIIHt": -2, 
+            "EcgTag": 0, 
+            "EcgV5Ht": -1, 
+            "PapHt": -3, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": -2, 
+            "EcgIIHt": -3, 
+            "EcgTag": 0, 
+            "EcgV5Ht": -2, 
+            "PapHt": -3, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": -3, 
+            "EcgIIHt": -2, 
+            "EcgTag": 0, 
+            "EcgV5Ht": -1, 
+            "PapHt": -3, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": -3, 
+            "EcgIIHt": -1, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -3, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": -1, 
+            "CvpHt": -4, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -2, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -4, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -2, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -5, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -2, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -5, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -2, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -5, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
+            "PapHt": -2, 
+            "SpHt": -1
+        }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -4, 
+            "EcgIIHt": 1, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 1, 
+            "PapHt": -1, 
+            "SpHt": 0
+        }, 
+        {
+            "AbpHt": 0, 
+            "CvpHt": -4, 
             "EcgIIHt": 3, 
             "EcgTag": 0, 
-            "EcgV5Ht": -3, 
-            "PapHt": -3, 
-            "SpHt": -2
+            "EcgV5Ht": 3, 
+            "PapHt": -1, 
+            "SpHt": 0
         }, 
         {
-            "AbpHt": -1, 
-            "CvpHt": -1, 
-            "EcgIIHt": 4, 
+            "AbpHt": 0, 
+            "CvpHt": -3, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -4, 
-            "PapHt": -3, 
-            "SpHt": -2
+            "EcgV5Ht": 0, 
+            "PapHt": -1, 
+            "SpHt": 0
         }, 
         {
-            "AbpHt": -1, 
-            "CvpHt": -1, 
-            "EcgIIHt": 5, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -5, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": -1, 
-            "EcgIIHt": 6, 
+            "AbpHt": 0, 
+            "CvpHt": -3, 
+            "EcgIIHt": -10, 
             "EcgTag": 0, 
             "EcgV5Ht": -6, 
-            "PapHt": -3, 
-            "SpHt": -2
+            "PapHt": -1, 
+            "SpHt": 0
         }, 
         {
-            "AbpHt": -1, 
-            "CvpHt": -1, 
-            "EcgIIHt": 7, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -7, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -1, 
+            "AbpHt": 0, 
             "CvpHt": -2, 
-            "EcgIIHt": 8, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -8, 
-            "PapHt": -3, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": -2, 
-            "EcgIIHt": 9, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -9, 
-            "PapHt": -3, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": -3, 
-            "EcgIIHt": 10, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -10, 
-            "PapHt": -3, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": -3, 
-            "EcgIIHt": 11, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -11, 
-            "PapHt": -3, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": -4, 
-            "EcgIIHt": 12, 
+            "EcgIIHt": -20, 
             "EcgTag": 0, 
             "EcgV5Ht": -12, 
-            "PapHt": -2, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -4, 
-            "EcgIIHt": 13, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -13, 
-            "PapHt": -2, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -5, 
-            "EcgIIHt": 13, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -13, 
-            "PapHt": -2, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -5, 
-            "EcgIIHt": 14, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -14, 
-            "PapHt": -2, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -5, 
-            "EcgIIHt": 15, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -15, 
-            "PapHt": -2, 
-            "SpHt": -1
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -4, 
-            "EcgIIHt": 16, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -16, 
-            "PapHt": -1, 
-            "SpHt": 0
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -4, 
-            "EcgIIHt": 16, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -16, 
-            "PapHt": -1, 
-            "SpHt": 0
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -3, 
-            "EcgIIHt": 17, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -17, 
-            "PapHt": -1, 
-            "SpHt": 0
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -3, 
-            "EcgIIHt": 17, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -17, 
             "PapHt": -1, 
             "SpHt": 0
         }, 
         {
             "AbpHt": 0, 
             "CvpHt": -2, 
-            "EcgIIHt": 18, 
-            "EcgTag": 0, 
-            "EcgV5Ht": -18, 
-            "PapHt": -1, 
-            "SpHt": 0
-        }, 
-        {
-            "AbpHt": 0, 
-            "CvpHt": -2, 
-            "EcgIIHt": 18, 
+            "EcgIIHt": -10, 
             "EcgTag": 3, 
-            "EcgV5Ht": -18, 
+            "EcgV5Ht": -6, 
             "PapHt": 0, 
             "SpHt": 0
         }, 
         {
             "AbpHt": 0, 
             "CvpHt": -3, 
-            "EcgIIHt": 19, 
+            "EcgIIHt": 3, 
             "EcgTag": 0, 
-            "EcgV5Ht": -19, 
+            "EcgV5Ht": 6, 
             "PapHt": 0, 
             "SpHt": 0
         }, 
         {
             "AbpHt": 0, 
             "CvpHt": -3, 
-            "EcgIIHt": 19, 
+            "EcgIIHt": 2, 
             "EcgTag": 0, 
-            "EcgV5Ht": -19, 
+            "EcgV5Ht": 4, 
             "PapHt": 0, 
             "SpHt": 0
         }, 
         {
             "AbpHt": 0, 
             "CvpHt": -3, 
-            "EcgIIHt": 19, 
+            "EcgIIHt": 1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -19, 
+            "EcgV5Ht": 2, 
             "PapHt": 0, 
             "SpHt": 0
         }, 
         {
             "AbpHt": 0, 
             "CvpHt": -2, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": 1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": 1, 
             "PapHt": -1, 
             "SpHt": 0
         }, 
         {
             "AbpHt": -1, 
             "CvpHt": -2, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": 0, 
             "PapHt": -1, 
             "SpHt": 0
         }, 
         {
             "AbpHt": -1, 
             "CvpHt": -1, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": 0, 
             "PapHt": -4, 
             "SpHt": 0
         }, 
         {
             "AbpHt": -1, 
             "CvpHt": -1, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": 0, 
             "PapHt": -9, 
             "SpHt": -1
         }, 
         {
             "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": -1, 
             "PapHt": -18, 
             "SpHt": -1
         }, 
         {
             "AbpHt": -9, 
             "CvpHt": 0, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": -1, 
             "PapHt": -19, 
             "SpHt": -2
         }, 
         {
             "AbpHt": -18, 
             "CvpHt": 1, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": -2, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": -2, 
             "PapHt": -20, 
             "SpHt": -4
         }, 
         {
             "AbpHt": -19, 
             "CvpHt": 1, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": -3, 
             "PapHt": -20, 
             "SpHt": -7
         }, 
         {
             "AbpHt": -20, 
             "CvpHt": 2, 
-            "EcgIIHt": 20, 
+            "EcgIIHt": -4, 
             "EcgTag": 0, 
-            "EcgV5Ht": -20, 
+            "EcgV5Ht": -4, 
             "PapHt": -19, 
             "SpHt": -10
         }, 
         {
             "AbpHt": -20, 
             "CvpHt": 2, 
-            "EcgIIHt": 19, 
+            "EcgIIHt": -6, 
             "EcgTag": 0, 
-            "EcgV5Ht": -19, 
+            "EcgV5Ht": -5, 
             "PapHt": -17, 
             "SpHt": -13
         }, 
         {
             "AbpHt": -19, 
             "CvpHt": 3, 
-            "EcgIIHt": 19, 
+            "EcgIIHt": -8, 
             "EcgTag": 0, 
-            "EcgV5Ht": -19, 
+            "EcgV5Ht": -5, 
             "PapHt": -16, 
             "SpHt": -15
         }, 
         {
             "AbpHt": -17, 
             "CvpHt": 3, 
-            "EcgIIHt": 19, 
+            "EcgIIHt": -9, 
             "EcgTag": 0, 
-            "EcgV5Ht": -19, 
+            "EcgV5Ht": -6, 
             "PapHt": -15, 
             "SpHt": -16
         }, 
         {
             "AbpHt": -16, 
             "CvpHt": 3, 
-            "EcgIIHt": 18, 
+            "EcgIIHt": -9, 
             "EcgTag": 0, 
-            "EcgV5Ht": -18, 
+            "EcgV5Ht": -6, 
             "PapHt": -14, 
             "SpHt": -17
         }, 
         {
             "AbpHt": -15, 
             "CvpHt": 2, 
-            "EcgIIHt": 18, 
+            "EcgIIHt": -9, 
             "EcgTag": 0, 
-            "EcgV5Ht": -18, 
+            "EcgV5Ht": -6, 
             "PapHt": -13, 
             "SpHt": -18
         }, 
         {
             "AbpHt": -14, 
             "CvpHt": 2, 
-            "EcgIIHt": 17, 
+            "EcgIIHt": -8, 
             "EcgTag": 0, 
-            "EcgV5Ht": -17, 
+            "EcgV5Ht": -5, 
             "PapHt": -12, 
             "SpHt": -19
         }, 
         {
             "AbpHt": -13, 
             "CvpHt": 1, 
-            "EcgIIHt": 17, 
+            "EcgIIHt": -5, 
             "EcgTag": 0, 
-            "EcgV5Ht": -17, 
+            "EcgV5Ht": -4, 
             "PapHt": -12, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -12, 
             "CvpHt": 1, 
-            "EcgIIHt": 16, 
+            "EcgIIHt": -3, 
             "EcgTag": 0, 
-            "EcgV5Ht": -16, 
+            "EcgV5Ht": -2, 
             "PapHt": -12, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -12, 
             "CvpHt": 0, 
-            "EcgIIHt": 16, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -16, 
+            "EcgV5Ht": -1, 
             "PapHt": -13, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -12, 
             "CvpHt": 0, 
-            "EcgIIHt": 15, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -15, 
+            "EcgV5Ht": -1, 
             "PapHt": -13, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -13, 
             "CvpHt": 0, 
-            "EcgIIHt": 14, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -14, 
+            "EcgV5Ht": -1, 
             "PapHt": -13, 
             "SpHt": -20
         }, 
         {
             "AbpHt": -13, 
             "CvpHt": 0, 
-            "EcgIIHt": 13, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -13, 
+            "EcgV5Ht": 0, 
             "PapHt": -12, 
             "SpHt": -19
         }, 
         {
             "AbpHt": -13, 
             "CvpHt": 0, 
-            "EcgIIHt": 13, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -13, 
+            "EcgV5Ht": 0, 
             "PapHt": -11, 
             "SpHt": -19
         }, 
         {
             "AbpHt": -12, 
             "CvpHt": 0, 
-            "EcgIIHt": 12, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -12, 
+            "EcgV5Ht": 0, 
             "PapHt": -10, 
             "SpHt": -18
         }, 
         {
             "AbpHt": -11, 
             "CvpHt": 1, 
-            "EcgIIHt": 11, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -11, 
+            "EcgV5Ht": 0, 
             "PapHt": -9, 
             "SpHt": -17
         }, 
         {
             "AbpHt": -10, 
             "CvpHt": 1, 
-            "EcgIIHt": 10, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -10, 
-            "PapHt": -9, 
+            "EcgV5Ht": 0, 
+            "PapHt": -8, 
             "SpHt": -16
         }, 
         {
             "AbpHt": -9, 
             "CvpHt": 2, 
-            "EcgIIHt": 9, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -9, 
+            "EcgV5Ht": 0, 
             "PapHt": -8, 
             "SpHt": -15
         }, 
         {
             "AbpHt": -8, 
             "CvpHt": 2, 
-            "EcgIIHt": 8, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -8, 
+            "EcgV5Ht": 0, 
             "PapHt": -8, 
             "SpHt": -14
         }, 
         {
             "AbpHt": -7, 
             "CvpHt": 2, 
-            "EcgIIHt": 7, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -7, 
-            "PapHt": -8, 
+            "EcgV5Ht": 0, 
+            "PapHt": -7, 
             "SpHt": -13
         }, 
         {
             "AbpHt": -7, 
             "CvpHt": 2, 
-            "EcgIIHt": 6, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -6, 
-            "PapHt": -8, 
+            "EcgV5Ht": 0, 
+            "PapHt": -7, 
             "SpHt": -12
         }, 
         {
             "AbpHt": -6, 
             "CvpHt": 2, 
-            "EcgIIHt": 5, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -5, 
+            "EcgV5Ht": 0, 
             "PapHt": -7, 
             "SpHt": -12
         }, 
         {
             "AbpHt": -6, 
             "CvpHt": 1, 
-            "EcgIIHt": 4, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -4, 
+            "EcgV5Ht": 0, 
             "PapHt": -7, 
             "SpHt": -11
         }, 
         {
             "AbpHt": -6, 
             "CvpHt": 1, 
-            "EcgIIHt": 3, 
+            "EcgIIHt": -1, 
             "EcgTag": 0, 
-            "EcgV5Ht": -3, 
+            "EcgV5Ht": 0, 
             "PapHt": -7, 
             "SpHt": -11
         }, 
         {
             "AbpHt": -5, 
             "CvpHt": 1, 
-            "EcgIIHt": 2, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -2, 
+            "EcgV5Ht": 0, 
             "PapHt": -7, 
             "SpHt": -10
         }, 
         {
             "AbpHt": -5, 
             "CvpHt": 1, 
-            "EcgIIHt": 1, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": -1, 
+            "EcgV5Ht": 0, 
             "PapHt": -7, 
             "SpHt": -10
         }, 
@@ -555,533 +555,227 @@ sinus6[50] = {
         {
             "AbpHt": -5, 
             "CvpHt": 0, 
-            "EcgIIHt": -1, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 1, 
+            "EcgV5Ht": 0, 
             "PapHt": -7, 
             "SpHt": -9
         }, 
         {
             "AbpHt": -5, 
             "CvpHt": 0, 
-            "EcgIIHt": -2, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 2, 
-            "PapHt": -7, 
+            "EcgV5Ht": 0, 
+            "PapHt": -6, 
             "SpHt": -9
         }, 
         {
-            "AbpHt": -5, 
+            "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": -3, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 3, 
-            "PapHt": -7, 
+            "EcgV5Ht": 0, 
+            "PapHt": -6, 
             "SpHt": -9
         }, 
         {
-            "AbpHt": -5, 
+            "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": -4, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 4, 
-            "PapHt": -7, 
-            "SpHt": -8
-        }, 
-        {
-            "AbpHt": -5, 
-            "CvpHt": 0, 
-            "EcgIIHt": -5, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 5, 
+            "EcgV5Ht": 0, 
             "PapHt": -6, 
             "SpHt": -8
         }, 
         {
             "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": -6, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 6, 
+            "EcgV5Ht": 0, 
             "PapHt": -6, 
             "SpHt": -8
         }, 
         {
             "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": -7, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 7, 
+            "EcgV5Ht": 0, 
+            "PapHt": -6, 
+            "SpHt": -8
+        }, 
+        {
+            "AbpHt": -4, 
+            "CvpHt": 0, 
+            "EcgIIHt": 0, 
+            "EcgTag": 0, 
+            "EcgV5Ht": 0, 
             "PapHt": -6, 
             "SpHt": -7
         }, 
         {
             "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": -8, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 8, 
+            "EcgV5Ht": 0, 
             "PapHt": -6, 
             "SpHt": -7
         }, 
         {
             "AbpHt": -4, 
             "CvpHt": 0, 
-            "EcgIIHt": -9, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 9, 
+            "EcgV5Ht": 0, 
             "PapHt": -6, 
             "SpHt": -7
         }, 
         {
-            "AbpHt": -4, 
+            "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -10, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 10, 
+            "EcgV5Ht": 0, 
             "PapHt": -6, 
             "SpHt": -7
         }, 
-        {
-            "AbpHt": -4, 
-            "CvpHt": 0, 
-            "EcgIIHt": -11, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 11, 
-            "PapHt": -6, 
-            "SpHt": -7
-        }, 
-        {
-            "AbpHt": -4, 
-            "CvpHt": 0, 
-            "EcgIIHt": -12, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 12, 
-            "PapHt": -6, 
-            "SpHt": -7
-        }, 
-        {
-            "AbpHt": -4, 
-            "CvpHt": 0, 
-            "EcgIIHt": -13, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 13, 
-            "PapHt": -6, 
-            "SpHt": -6
-        }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -13, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 13, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -6
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -14, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 14, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -6
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -15, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 15, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -6
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -16, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 16, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -6
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -16, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 16, 
-            "PapHt": -5, 
-            "SpHt": -6
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -17, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 17, 
-            "PapHt": -5, 
-            "SpHt": -6
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -17, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 17, 
-            "PapHt": -5, 
-            "SpHt": -6
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -18, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 18, 
-            "PapHt": -5, 
-            "SpHt": -6
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -18, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 18, 
-            "PapHt": -5, 
-            "SpHt": -6
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -19, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 19, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -5
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -19, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 19, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -5
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -19, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 19, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -5
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -20, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 20, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -5
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -20, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 20, 
-            "PapHt": -5, 
-            "SpHt": -5
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -20, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 20, 
-            "PapHt": -5, 
-            "SpHt": -5
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -20, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 20, 
+            "EcgV5Ht": 0, 
             "PapHt": -5, 
             "SpHt": -4
         }, 
         {
             "AbpHt": -3, 
             "CvpHt": 0, 
-            "EcgIIHt": -20, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 20, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -20, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 20, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -20, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 20, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -20, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 20, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -20, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 20, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -19, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 19, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -19, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 19, 
-            "PapHt": -5, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -19, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 19, 
-            "PapHt": -5, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -18, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 18, 
-            "PapHt": -5, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -18, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 18, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -17, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 17, 
-            "PapHt": -5, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -3, 
-            "CvpHt": 0, 
-            "EcgIIHt": -17, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 17, 
+            "EcgV5Ht": 0, 
             "PapHt": -4, 
             "SpHt": -4
         }, 
         {
             "AbpHt": -2, 
             "CvpHt": 0, 
-            "EcgIIHt": -16, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 16, 
+            "EcgV5Ht": 0, 
             "PapHt": -4, 
             "SpHt": -4
         }, 
         {
             "AbpHt": -2, 
             "CvpHt": 0, 
-            "EcgIIHt": -16, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 16, 
+            "EcgV5Ht": 0, 
             "PapHt": -4, 
             "SpHt": -4
         }, 
         {
             "AbpHt": -2, 
             "CvpHt": 0, 
-            "EcgIIHt": -15, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 15, 
-            "PapHt": -4, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -14, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 14, 
-            "PapHt": -4, 
-            "SpHt": -4
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -13, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 13, 
+            "EcgV5Ht": 0, 
             "PapHt": -4, 
             "SpHt": -3
         }, 
         {
             "AbpHt": -2, 
             "CvpHt": 0, 
-            "EcgIIHt": -13, 
+            "EcgIIHt": 0, 
             "EcgTag": 0, 
-            "EcgV5Ht": 13, 
+            "EcgV5Ht": 0, 
             "PapHt": -4, 
             "SpHt": -3
         }, 
         {
             "AbpHt": -2, 
             "CvpHt": 0, 
-            "EcgIIHt": -12, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 12, 
-            "PapHt": -4, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -11, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 11, 
-            "PapHt": -4, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -10, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 10, 
-            "PapHt": -4, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -9, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 9, 
-            "PapHt": -4, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -8, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 8, 
-            "PapHt": -4, 
-            "SpHt": -3
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -7, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 7, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -6, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 6, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -5, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 5, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -2, 
-            "CvpHt": 0, 
-            "EcgIIHt": -4, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 4, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": 0, 
-            "EcgIIHt": -3, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 3, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": 0, 
-            "EcgIIHt": -2, 
-            "EcgTag": 0, 
-            "EcgV5Ht": 2, 
-            "PapHt": -3, 
-            "SpHt": -2
-        }, 
-        {
-            "AbpHt": -1, 
-            "CvpHt": 0, 
-            "EcgIIHt": -1, 
+            "EcgIIHt": 0, 
             "EcgTag": 1, 
-            "EcgV5Ht": 1, 
-            "PapHt": -3, 
-            "SpHt": -2
+            "EcgV5Ht": 0, 
+            "PapHt": -4, 
+            "SpHt": -3
         }
     ]
 }
\ No newline at end of file
