@@ -49,8 +49,7 @@ document.addEventListener('DOMContentLoaded', () => {
         hamburger.classList.toggle('change');
         toggleMenu(menu);
         if (myAccountMenu) myAccountMenu.style.display = 'none';
-    }); 
-	*/
+    }); */
 
     myAccount.addEventListener('click', (e) => {
 		e.stopPropagation();
@@ -117,9 +116,6 @@ document.addEventListener('DOMContentLoaded', () => {
 			// Update global variable and save
 			window.UserImageStr = newValue === 'gallery' ? 'styled' : 'photo';
 			setCookie('images', newValue, 30);
-			if (typeof SetPatientImage === 'function') {
-				SetPatientImage();
-			}
 		});
 	}
 	
@@ -418,7 +414,7 @@ document.addEventListener('DOMContentLoaded', () => {
 			}
 		})
 		.catch(error => {
-			// console.error('Error:', error);
+			console.error('Error:', error);
 			if (uploadStatus) {
 				uploadStatus.textContent = 'An error occurred. Please try again.';
 			}
@@ -452,7 +448,7 @@ document.addEventListener('DOMContentLoaded', () => {
 				}
 			})
 			.catch(error => {
-				// console.error('Error:', error);
+				console.error('Error:', error);
 				alert('An error occurred. Please try again.');
 			});
 		}
@@ -491,6 +487,57 @@ document.addEventListener('DOMContentLoaded', () => {
         removeProfilePictureButton.addEventListener('click', removeProfilePicture);
     }
 	
+	if (viewMyCasesBtn) {
+		viewMyCasesBtn.addEventListener('click', function(e) {
+			if (handleSettingsNavigation(e, 'cases')) {
+				return;
+			}
+			e.preventDefault();
+			e.stopPropagation();
+			
+			if (document.querySelector('.view-cases')) {
+				document.querySelector('.view-cases').click();
+			} else {
+				sessionStorage.setItem('showCases', 'true');
+				window.location.href = '/settings';
+			}
+		});
+	}
+
+	if (viewMySettingsBtn) {
+		viewMySettingsBtn.addEventListener('click', function(e) {
+			if (handleSettingsNavigation(e, 'details')) {
+				return;
+			}
+			e.preventDefault();
+			e.stopPropagation();
+			
+			if (document.querySelector('.view-settings')) {
+				document.querySelector('.view-settings').click();
+			} else {
+				sessionStorage.setItem('showDetails', 'true');
+				window.location.href = '/settings';
+			}
+		});
+	}
+
+	if (changeMySettingsBtn) {
+		changeMySettingsBtn.addEventListener('click', function(e) {
+			if (handleSettingsNavigation(e, 'change')) {
+				return;
+			}
+			e.preventDefault();
+			e.stopPropagation();
+			
+			if (document.querySelector('.change-settings')) {
+				document.querySelector('.change-settings').click();
+			} else {
+				sessionStorage.setItem('showChangeSettings', 'true');
+				window.location.href = '/settings';
+			}
+		});
+	}
+	
 });
 
 function handleSidebarClick(action) {
@@ -540,7 +587,7 @@ async function showProModal(status, expirationDate) {
     // console.log('showProModal called with status:', status, 'and expirationDate:', expirationDate);
     var modal = document.getElementById('proStatusModal');
     if (!modal) {
-        // console.error('Pro Status Modal not found');
+        console.error('Pro Status Modal not found');
         return;
     }
 
@@ -553,7 +600,7 @@ async function showProModal(status, expirationDate) {
             setupProModal(status, expirationDate, groupData.isIndividual, modal, modalContent);
         })
         .catch(error => {
-            // console.error('Error fetching user group:', error);
+            console.error('Error fetching user group:', error);
             // Fallback to regular modal if fetch fails
             setupProModal(status, expirationDate, true, modal, modalContent);
         });
@@ -595,7 +642,7 @@ function setupProModal(status, expirationDate, isIndividual, modal, modalContent
     var upgradeNoBtn2 = modal.querySelector('.upgradeNo');
 
     if (!statusEl || !expirationEl || !featuresEl || !upgradeYesBtn2 || !upgradeNoBtn2) {
-        // console.error('One or more elements not found in Pro Status Modal');
+        console.error('One or more elements not found in Pro Status Modal');
         return;
     }
 
@@ -657,7 +704,7 @@ function setupProModal(status, expirationDate, isIndividual, modal, modalContent
                 }
                 ClickBtnTime();
             } catch (error) {
-                // console.error('Error in upgrade process:', error);
+                console.error('Error in upgrade process:', error);
             }
         }
         
@@ -732,27 +779,20 @@ function showDemoModal() {
             }
         }
     } else {
-        // console.error('Demo modal not found');
+        console.error('Demo modal not found');
     }
 }
 
 /******************************************************************
-***  session handler  ***
+***  session code  ***
 ******************************************************************/
 
-
 // Global flag to track settings navigation
 document.addEventListener('DOMContentLoaded', function() {
     // Clear flag only if we're not on settings page
     if (!window.location.pathname.includes('/settings')) {
         sessionStorage.removeItem('navigatingToSettings');
     }
-    if (!window.location.pathname.includes('/cases')) {
-        sessionStorage.removeItem('navigatingToCases');
-    }
-    if (!window.location.pathname.includes('/profile')) {
-        sessionStorage.removeItem('navigatingToProfile');
-    }
     
     // Settings link detection
     function addSettingsListeners() {
@@ -774,18 +814,6 @@ document.addEventListener('DOMContentLoaded', function() {
                 sessionStorage.setItem('navigatingToSettings', 'true');
             }, true);
         });
-
-        settingsElements.forEach(element => {
-            element.addEventListener('click', () => {
-                sessionStorage.setItem('navigatingToCases', 'true');
-            }, true);
-        });
-
-        settingsElements.forEach(element => {
-            element.addEventListener('click', () => {
-                sessionStorage.setItem('navigatingToProfile', 'true');
-            }, true);
-        });
     }
 
     // Initial setup
@@ -910,11 +938,7 @@ document.addEventListener('click', (e) => {
 // Session termination handler
 window.addEventListener('pagehide', function(e) {
     const isSettingsPage = window.location.pathname.includes('/settings');
-    const isCasesPage = window.location.pathname.includes('/cases');
-    const isProfilePage = window.location.pathname.includes('/profile');
     const goingToSettings = sessionStorage.getItem('navigatingToSettings') === 'true';
-    const goingToCases = sessionStorage.getItem('navigatingToCases') === 'true';
-    const goingToProfile = sessionStorage.getItem('navigatingToProfile') === 'true';
     const sessionCookie = document.cookie.split(';')
         .find(c => c.trim().startsWith('session='));
     const sessionValue = sessionCookie ? sessionCookie.split('=')[1].trim() : 'on';
@@ -925,11 +949,7 @@ window.addEventListener('pagehide', function(e) {
     // 3. Session is set to off for super
 	// 4. Is a page refresh
     if (isSettingsPage || 
-		isCasesPage || 
-		isProfilePage || 
         goingToSettings || 
-        goingToCases ||
-        goingToProfile ||
         sessionValue === 'off' || 
         performance.navigation.type === 1) {
         return;
@@ -996,6 +1016,7 @@ document.querySelectorAll('.copy-icon').forEach(icon => {
 });
 
 /* hide copy icon when no overflow */
+
 window.addEventListener('load', () => {
     document.querySelectorAll('.copy-icon').forEach(icon => {
         const textEl = icon.previousElementSibling.querySelector('.inner-text');
@@ -1005,62 +1026,4 @@ window.addEventListener('load', () => {
             icon.style.removeProperty('display');
         }
     });
-}); 
-
-
-// Debug Logging Toggle
-const debugLoggingToggle = document.getElementById('debug-logging-toggle');
-if (debugLoggingToggle) {
-    const debugButtons = debugLoggingToggle.querySelectorAll('.toggle-option');
-    debugButtons.forEach(button => {
-        button.addEventListener('click', function() {
-            const mode = this.getAttribute('data-value');
-            
-            fetch('/api/toggle_debug_mode.php', {
-                method: 'POST',
-                headers: {'Content-Type': 'application/x-www-form-urlencoded'},
-                body: 'mode=' + mode
-            })
-            .then(response => response.json())
-            .then(data => {
-                if (data.success) {
-                    debugButtons.forEach(btn => btn.classList.remove('active'));
-                    this.classList.add('active');
-                    console.log('Debug mode set to:', mode);
-                } else {
-                    console.error('Failed to toggle debug mode:', data.message);
-                }
-            })
-            .catch(error => console.error('Error:', error));
-        });
-    });
-}
-
-
-// ================================================================
-// SESSION KEEPALIVE FOR LONG-RUNNING SIMULATIONS
-// ================================================================
-
-let sessionKeepaliveInterval = null;
-
-function startSessionKeepalive() {
-    if (sessionKeepaliveInterval) {
-        console.log("Session keepalive already running");
-        return;
-    }
-    console.log("Starting session keepalive (pings every 5 minutes)");
-    sessionKeepaliveInterval = setInterval(() => {
-        fetch('/api/keepalive.php', {method: 'POST'})
-            .then(r => r.json())
-            .then(d => console.log('Session keepalive ping:', d))
-            .catch(e => console.error('Keepalive error:', e));
-    }, 300000);
-}
-
-function stopSessionKeepalive() {
-    if (sessionKeepaliveInterval) {
-        console.log("Stopping session keepalive");
-        clearInterval(sessionKeepaliveInterval);
-        sessionKeepaliveInterval = null;
-    }
-}
+}); 
\ No newline at end of file
